@@ -38,7 +38,7 @@ class BaseModel(object):
         else:
             return pd.Series(self.params)
 
-    def set_paramerters(self, params=None, **kwargs):
+    def set_parameters(self, params=None, **kwargs):
         """
         Set model parameters as dict {"x": 1}, Series (pd.Series(1, index=["x"])) or
         parameter by parameter (x=1)
